@@ -3,12 +3,12 @@
 
 try:
     from trytond.modules.payment_gateway.tests.test_payment_gateway import (
-        suite, create_payment_gateway, create_payment_transaction,
-        create_payment_profile)
+        create_payment_gateway, create_payment_profile,
+        create_payment_transaction, suite)
 except ImportError:
     from .test_payment_gateway import (
-        suite, create_payment_gateway, create_payment_transaction,
-        create_payment_profile)
+        create_payment_gateway, create_payment_profile,
+        create_payment_transaction, suite)
 
 __all__ = ['suite', 'create_payment_gateway', 'create_payment_transaction',
     'create_payment_profile']
