@@ -1,21 +1,24 @@
 # The COPYRIGHT file at the top level of this repository contains
 # the full copyright notices and license terms.
 import re
-from uuid import uuid4
-from decimal import Decimal
+
 from datetime import datetime
+from decimal import Decimal
+from uuid import uuid4
 
 import yaml
-from babel import numbers, dates
-from trytond.pool import Pool, PoolMeta
-from trytond.pyson import Eval, If, Bool
-from trytond.wizard import Wizard, StateView, StateTransition, \
-    Button, StateAction
-from trytond.transaction import Transaction
-from trytond.model import (ModelSQL, ModelView, Workflow, fields,
-    DeactivableMixin)
+
+from babel import dates, numbers
+
 from trytond.exceptions import UserError
 from trytond.i18n import gettext
+from trytond.model import (
+    DeactivableMixin, ModelSQL, ModelView, Workflow, fields)
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Bool, Eval, If
+from trytond.transaction import Transaction
+from trytond.wizard import (
+    Button, StateAction, StateTransition, StateView, Wizard)
 
 READONLY_IF_NOT_DRAFT = {'readonly': Eval('state') != 'draft'}
 STATES = {
@@ -142,7 +145,10 @@ class PaymentTransaction(Workflow, ModelSQL, ModelView):
     )
     party = fields.Many2One(
         'party.party', 'Party', required=True, ondelete='RESTRICT',
-        depends=['state'], states=READONLY_IF_NOT_DRAFT,
+        context={
+            'company': Eval('company', -1),
+            },
+        depends=['company', 'state'], states=READONLY_IF_NOT_DRAFT,
     )
     payment_profile = fields.Many2One(
         'party.payment_profile', 'Payment Profile',
@@ -787,14 +793,14 @@ class TransactionLog(ModelSQL, ModelView):
 
 WHEN_CP = {
     # Required if card is present
-    'required': Bool(Eval('card_present')),
+    #'required': Bool(Eval('card_present')),
 
     # Readonly if card is **not** present
     'readonly': ~Bool(Eval('card_present'))
 }
 WHEN_CNP = {
     # Required if card is not present
-    'required': ~Bool(Eval('card_present')),
+    #'required': ~Bool(Eval('card_present')),
 
     # Readonly if card is present
     'readonly': Bool(Eval('card_present'))
@@ -1092,7 +1098,7 @@ class TransactionUseCard(Wizard):
         'payment_gateway.transaction_use_card_view_form',
         [
             Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Authorize', 'authorize', 'tryton-go-next'),
+            Button('Authorize', 'authorize', 'tryton-forward'),
             Button('Capture', 'capture', 'tryton-ok', default=True),
         ]
     )
@@ -1172,11 +1178,7 @@ class AccountMove(metaclass=PoolMeta):
 
     @classmethod
     def _get_origin(cls):
-        res = super(AccountMove, cls)._get_origin()
-
-        if 'payment_gateway.transaction' not in res:
-            res.append('payment_gateway.transaction')
-        return res
+        return super()._get_origin() + ['payment_gateway.transaction']
 
 
 class AccountMoveLine(metaclass=PoolMeta):
@@ -1184,11 +1186,7 @@ class AccountMoveLine(metaclass=PoolMeta):
 
     @classmethod
     def _get_origin(cls):
-        res = super(AccountMoveLine, cls)._get_origin()
-
-        if 'payment_gateway.transaction' not in res:
-            res.append('payment_gateway.transaction')
-        return res
+        return super()._get_origin() + ['payment_gateway.transaction']
 
 
 class CreateRefund(Wizard):
